
# q-expansion of newform 483.4.a.i, downloaded from the LMFDB on 14 January 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 483
weight = 4
poly_data = [-192, 8716, 1772, -5403, -401, 861, 34, -51, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0], 1], [[-11, 0, 1, 0, 0, 0, 0, 0, 0], 1], [[8, -17, -1, 1, 0, 0, 0, 0, 0], 1], [[118608, 18774, -73899, 8922, 2445, -1535, 426, 57, -18], 5896], [[79896, -106520, -135262, 18519, 28288, -905, -1811, 12, 35], 5896], [[-31920, -281392, -44774, 171153, -1704, -17943, 923, 492, -39], 5896], [[30544, 1974, -29131, 948, 5457, -25, -368, -3, 8], 536], [[175760, 604526, -212909, -207841, 57465, 18610, -4687, -487, 115], 5896]]

hecke_ring_character_values = None
aps_data = [[1, -1, 0, 0, 0, 0, 0, 0, 0], [3, 0, 0, 0, 0, 0, 0, 0, 0], [4, 0, 0, 0, -1, 0, 0, 0, 0], [7, 0, 0, 0, 0, 0, 0, 0, 0], [5, 2, -1, 0, 1, 0, 0, -1, 0], [12, 2, 1, -1, 0, 1, 0, 0, -1], [17, 3, 0, 2, -1, 1, 1, 1, 0], [1, 4, -3, 2, -1, -2, 2, -1, 2], [-23, 0, 0, 0, 0, 0, 0, 0, 0], [44, 5, 1, 4, 5, -1, -1, 1, -1], [-13, 1, -10, -2, 5, -1, 3, -3, -2], [37, -4, 2, 5, 5, -9, -2, 2, -2], [85, 11, -3, 1, 15, 0, -3, 0, 0], [-5, 25, -8, -2, -2, 3, -5, -5, 0], [102, 4, -11, -13, 8, 1, 0, -1, 0], [96, 0, -21, -3, -1, 1, 0, 3, 2], [79, -3, 24, -6, 11, -15, 1, 0, 1], [193, 17, 7, -3, -24, 12, -9, 10, 2], [-123, 16, -59, 8, 5, -14, 4, -4, 3], [171, 74, 24, -1, -24, 7, 4, 2, 10], [67, -9, 16, -18, -9, 19, 1, 7, -6], [-139, 23, -18, 22, -21, -15, -7, -7, 6], [194, 2, 27, -9, 25, -19, -4, -4, 5], [133, 142, 32, -7, -16, -5, -20, -6, -20], [102, -121, 39, 22, -25, -17, -23, 13, 5], [199, 87, 44, 12, -1, 35, 15, 10, 13], [270, 6, 43, 3, 8, -37, -6, 1, 14], [-46, 155, 17, 20, -14, 9, 1, 7, -15], [-158, 134, -72, 2, 5, -14, 26, 4, 2], [321, 151, 27, -5, -11, -46, 3, 7, -1], [171, 232, 65, -6, 42, 2, 34, -29, 6], [64, 181, -108, -51, -11, 34, -13, -8, -23], [423, 169, -15, 41, 15, -38, 19, 12, 20], [239, -257, 93, -11, 57, 48, -1, 9, 17], [-12, 25, -67, 6, 46, -19, 21, 20, 6], [108, 248, -9, 15, 28, 29, -8, 15, -10], [-440, 27, 45, -32, 48, 29, -17, -12, 12], [-317, -335, 100, -52, -23, 61, -11, 20, 9], [-202, -231, -12, 15, 99, -24, 3, -28, 9], [3, -65, -156, 30, 53, -65, 9, -27, 28], [455, 95, -79, -73, 59, -24, -21, 7, -41], [-462, -310, 35, 87, -89, -21, -28, 10, -15], [-273, -282, 2, -57, 18, 73, -2, 5, 39], [-638, 108, -11, 9, 48, 35, 16, 17, -2], [424, 394, 163, 5, -112, 55, -52, 30, 21], [-662, 389, 97, 14, 27, -69, -19, -20, -14], [-1108, -113, 272, 53, 131, -70, 37, -38, -25], [-124, -219, -34, 45, -57, -36, 53, -9, 36], [576, -10, 74, 100, 141, 48, 46, 12, 8], [118, -608, 259, -87, 3, 103, -8, 21, 16], [120, -139, 268, -19, -17, 152, 33, -33, -10], [520, -47, 94, -53, 197, 4, -47, 43, -8], [-543, 957, -55, -87, -9, 88, 7, -22, 4], [904, -813, 230, -137, 54, 114, -13, -1, 12], [-327, -884, -182, 113, 84, 53, -28, 5, -35], [1175, -11, 155, -9, 105, -54, 31, -112, -36], [2209, -442, -66, 29, -140, -31, 0, 94, 52], [845, -335, 104, 70, 157, 31, -93, 31, -54], [318, -394, 76, 28, 24, 100, -68, 73, 9], [-883, 26, 11, 32, -166, -84, -62, -12, 27], [-391, 356, -35, 42, 83, -134, -40, 86, 61], [-75, -161, -219, -23, -176, 50, -141, -35, -29], [-304, 255, -547, 52, -447, 73, -15, 75, -5], [1830, -472, -172, -124, 372, -14, 14, -47, -21], [1147, 364, 98, -85, -32, 215, 4, -31, -115], [-317, -799, -389, 107, -41, -80, -39, 79, 47], [-2649, 602, -40, 45, 100, 59, -10, 47, -5], [-2787, 216, -38, -75, -48, -171, -14, -110, 46], [3760, -857, -65, -168, -31, 27, -43, -51, -91], [1202, -249, -218, 133, -9, 12, 123, 41, -20], [2608, 61, -439, 30, -115, 11, 119, -27, 45], [841, -685, -79, 53, -117, -158, 55, 73, -41], [-105, 200, -297, -74, 144, -196, 74, -17, 24], [-616, 148, 95, -275, 555, -159, -62, -60, 15], [-824, 1581, -254, -47, -200, -46, -3, -51, 92], [3321, 255, -42, 64, -123, -91, 57, -15, 152], [2334, 38, -41, 329, -163, 11, 164, -62, 67], [1996, 24, 510, 116, 170, -60, -56, -172, -22], [1572, -525, 178, 61, -61, -58, -23, -114, -41], [999, -157, -562, -92, 245, -75, -147, 25, -6], [-1821, 406, -325, 228, -147, 138, 86, 182, -139], [-3671, -257, -256, 152, 234, 107, 129, 97, -46], [2709, -1774, 5, -132, -256, -32, -56, -83, -68], [1516, -306, 407, 199, 380, -61, 106, 11, 124], [3969, -1199, -38, 120, 225, 121, -277, 51, -12], [211, -1062, 545, 142, -194, 50, 90, -32, -71], [40, -1387, -98, 203, -455, -46, -79, 197, -38], [-186, -1537, 342, 75, 139, 120, 155, -51, 66], [1124, -1039, 566, 73, 113, 82, 177, 191, 88], [-4507, -9, 549, 375, -279, 70, -3, -56, 112], [269, -1204, -214, 11, 13, -79, 198, 108, -52], [4279, -453, -716, -36, 77, 357, -43, 39, 4], [5226, -1819, 209, -450, 33, -1, 7, -231, -23], [3351, -1566, -120, -213, -390, 19, 104, 180, 232], [-2126, -561, -270, 95, 101, -130, -73, 169, -68], [-3014, -1275, 822, -89, 289, -310, -3, -73, 38], [-971, -554, -614, -173, 276, -291, -122, 59, -103], [2418, -2500, -180, 20, -372, 316, 36, -32, -72], [-1596, -787, -231, -24, -130, -429, 173, -68, 46], [-2597, -520, 8, -63, 324, 173, -100, -243, -181], [-4268, -1047, -32, 189, 121, 234, 105, -153, -50], [-167, -767, 143, 297, 66, 88, 161, 17, 259], [797, 1487, -860, 290, 620, -415, -43, -109, 16], [1022, -1706, -519, -245, -350, 135, -26, 15, -30], [3624, -1274, -957, 51, -201, 171, -196, 314, -167], [3096, 338, -654, 338, -344, 228, -82, 214, 98], [-6208, 192, 58, -36, 98, -90, -6, -9, 79], [3231, 2490, 161, -204, -582, 512, -174, 8, -71], [-227, 836, -506, 421, -570, 31, -78, 282, -22], [-2142, -2299, -558, 71, -69, -388, 1, 193, -34], [-2225, 894, 610, -99, 112, 405, 56, 4, -120], [17, 752, -850, -191, 295, 251, -174, -154, 86], [951, 1482, 50, 225, 104, -601, 152, -124, 206], [2100, -847, -545, -78, -14, -239, -109, -41, 359], [-11069, 415, -996, 166, -87, -75, 53, -215, -144], [-6071, -486, 241, -70, -94, 326, 88, -87, -186], [-3263, 1253, 1499, -425, -900, 62, -209, 164, 78], [-5478, -223, 504, 293, 503, 112, -115, -91, -56], [4801, 1841, 291, -443, 233, -206, 321, -59, 113], [-8770, 44, 597, -103, 887, -289, 302, -452, 7], [991, -662, 931, 324, 305, 236, -112, 335, -100], [-4633, -3597, 371, 419, -495, 4, -215, 566, 90], [-680, 199, 523, -466, 460, -369, -351, -119, -103], [-349, 3071, 324, 44, 405, 33, -83, 225, 228], [-9352, 436, -357, -267, 730, 341, -46, -408, -291], [502, 572, 553, -119, -611, 373, 52, -33, -92], [-1014, -211, -359, 40, 94, 963, -357, 119, 89], [50, -647, -39, -544, 279, 23, -17, 29, 67], [2536, -2549, 1126, -573, 751, 96, -87, -280, 245], [-2441, 307, -299, -281, -710, 208, -85, 63, 261], [-4497, 1241, 944, -154, 97, 9, 55, -13, -216], [-9177, 2197, -184, -332, -93, 321, 185, -250, -279], [-14102, -1311, 886, -27, -473, -450, -231, 125, -124], [-2622, -1504, 1229, -443, 165, 393, -330, 198, -153], [2719, -818, 352, 903, 44, -51, 154, -383, 1], [1231, 5186, -1427, 256, -422, 340, 98, 272, -39], [-845, 1698, 644, -231, 87, -77, -220, -258, -108], [-11002, 3046, 487, 23, -405, -11, 414, 93, 10], [4468, 2741, 346, -213, -1402, 512, -235, -229, -62], [6117, 306, -298, -711, 988, -187, 108, -216, -256], [-2296, 1841, -343, 782, 365, -419, -29, 367, 305], [-296, 2006, -392, -412, 1118, 166, 362, -188, -46], [-3058, 2867, -923, 74, -1349, -233, -17, -70, -328], [-10480, 2114, 661, -135, -121, -47, -674, -69, -666], [5775, 5585, -1132, -316, -269, -137, 263, -137, 160], [727, 2742, 830, 239, -1014, -431, 440, 2, 296], [205, 826, -1471, 642, 1306, -606, 530, -98, 151], [-6342, 1632, -1941, -33, -664, 189, 368, -245, -154], [-2789, 642, -1513, -320, -1304, -248, -62, 72, 91], [-2026, 1086, -1452, 420, -542, 526, 110, 404, -414], [-4215, -316, 188, 119, 508, 623, -260, -95, -117], [8646, 2262, 354, -508, -1024, 138, 42, -398, 294], [-18165, 2642, -228, 159, -416, 303, 480, 222, 302], [1207, -1276, -1384, -231, 642, -405, -370, -350, 266], [652, -2718, -924, -40, -553, -98, 654, -312, 54], [-1207, 2382, -1339, -316, -834, 672, -306, 360, 161], [-12139, 897, 1358, 184, -1003, 645, 27, 283, 58], [6053, 175, 1191, 221, 303, -470, -17, -85, -271], [2787, -341, -719, 861, -389, 474, -399, -4, -72], [5598, -7169, 1428, 729, -54, 112, 219, 347, 178], [497, 1700, -2263, 250, 816, -716, 152, 130, -103], [5570, 1024, 1588, 44, -486, 156, -834, -37, 47], [1286, 130, -616, -804, 1186, -318, -66, -518, 236], [-12310, -6269, 1863, -250, 774, 7, 129, -457, -223], [17561, -82, 267, 132, 918, 620, -444, 355, -278], [-3095, -3567, -1290, 162, 413, -787, -105, 555, -56], [9176, -5396, 298, -1020, -204, 786, 238, 201, 499], [3601, -1567, -320, -626, 519, 709, -69, -487, -574], [-12768, -5237, 236, 95, 1431, -1196, 395, 141, 8], [20670, 724, 1546, 332, 462, 766, -210, 321, -181], [-8367, -3115, 147, -273, 1562, 966, -425, -294, -354], [-3979, 1576, 9, 228, 82, -1422, -516, -322, -379], [5435, -1620, -2129, 462, -1260, 116, 338, -117, 318], [-3135, -1099, -310, 988, 287, -269, 183, 615, -424], [-5382, 4700, -756, 1198, -1444, -826, 88, -430, 38], [3401, 5485, -1456, 92, -653, -247, -273, -599, -2], [-10522, -4578, 1018, -96, 388, -380, -496, 297, 621], [-13478, -2393, -360, 885, 1989, -314, 623, -17, 384], [-4992, 5085, 1395, 26, 181, 899, -355, 440, 184], [19805, 2374, -393, 470, -1735, -898, -230, -66, 77], [4977, -167, 598, -1064, -5, 625, -103, -170, -1051], [-4395, 379, 2452, -14, 298, -699, 581, 713, 34], [-4493, 2997, -1084, -948, -813, 1415, 261, -540, -611], [16767, 5646, -1233, 592, 240, -574, 576, 365, 592], [-5245, 3817, 1715, -1509, -5, 466, 171, -284, -92], [-10285, 563, 2016, 478, -960, 21, -271, -195, 324], [17317, 2376, 3680, -841, 698, 491, 244, -189, 1], [-17016, 1656, -489, -601, 859, -333, -154, -376, -261], [4388, -5007, -45, -592, 661, -303, 477, -482, -516], [-8686, 451, -43, 666, 365, -1825, 401, -765, -209], [-5808, 4809, 332, -813, -233, -104, -531, -877, 350], [-10815, 7761, 1013, -637, -477, 806, -271, 869, -317], [-33679, -5651, 1235, -733, 940, -46, 453, -459, 75], [-550, -1023, -374, 177, -1217, 844, 507, -368, -407], [-17877, 559, -2157, 775, 1052, -1652, -43, 212, 6], [-14143, 5222, -1018, -1309, 1036, -1015, -76, -724, -292], [-8331, -7360, 1776, -421, 904, 95, 598, 258, 308], [26451, -3351, 2373, 265, 2198, -580, 369, 37, 261], [4062, -8346, 1510, -828, 700, 262, 14, 148, 328], [-2176, 1773, -581, 190, 139, -213, 289, 580, 718], [14842, -6791, 4081, -928, -84, 1083, 13, -246, -116], [-9628, 1064, -2360, -436, 68, 316, 856, 72, -48], [15025, -7627, 1835, 691, -1917, -282, 501, 41, -367], [-9430, -6032, -818, -34, 1930, -834, 370, 5, -11], [4149, -2710, -128, 1475, -487, 563, -404, 582, -398], [-10733, -5556, -1442, 179, -706, -1565, -852, 379, 191], [-16036, -1755, 1197, 160, 1993, 481, -769, 779, -159], [4530, -1299, -2870, 681, -219, -18, 405, -731, 698], [6234, -641, -938, -1149, -65, 328, -773, -983, -228], [-15377, -2519, 2164, -1472, -1171, -391, 231, 201, -120], [15962, 5360, 1003, -421, 294, 169, 512, 729, -252], [14119, 1933, -644, 210, 3569, -2057, 81, -14, -85], [-26195, 4415, -1924, 216, -399, 271, 197, 989, 664], [6183, 1703, 3491, -541, -1130, 1956, -169, -355, 121], [10478, 624, 923, 439, -884, 1147, 1122, -640, 877], [-3226, -7687, -2918, 511, -1445, 196, 65, -363, -240], [1582, -3845, -588, 1291, 1811, 996, 105, 196, -579], [3962, 5516, 1097, -505, 624, 827, -670, 918, -897], [38554, 6301, 139, -430, -2201, -495, -677, -325, -51], [10216, 8931, 1771, 120, -1139, -935, -791, -253, -375], [26750, 1186, -3470, 1378, -1786, -750, -292, 689, -73], [16635, -7112, 474, -395, 3256, 465, 20, -161, -429], [39019, -8228, -4076, 1407, -754, -1127, 738, 12, 440], [-8918, -5074, -3422, -102, -808, -488, 1202, -378, 1262], [42574, -6941, 12, -719, 2645, -80, -67, -350, 37], [-5335, -3067, 3740, -542, 1093, 2081, 609, -780, 509], [9089, 3891, 1698, 8, -2919, 539, 157, 75, -884], [4264, -5276, -520, -1384, -776, -360, 892, 40, 432], [-13228, -12154, -1721, 77, -418, 501, 744, 174, 571], [11353, 1953, 850, -1022, -1515, -423, -1437, -849, -62], [17440, -3757, -234, -849, 343, 634, -435, -1004, -223], [-8690, -2587, -477, -1296, -1154, 495, 203, -245, -1337], [-41068, -687, -54, -769, 467, -556, -751, -483, 400], [-7546, -8288, 200, -160, -2670, 1424, -2060, 174, -694], [10379, 4719, -4811, 281, -1054, -238, 897, -1346, -100], [20885, 2986, -126, 241, 280, 223, -672, 172, -570], [35550, -6196, -1097, -1501, -2174, -511, 300, -907, -576], [13908, -6118, 2983, 535, -475, 1153, -476, 698, -857], [7964, 2675, -1013, 900, 1031, -1281, 409, -541, 1107], [10927, 3735, -2232, 402, -2209, 1597, -583, 765, 214], [-23951, -8202, 4585, -470, 1109, 34, 1148, 289, -528], [-18604, -9639, 2812, -549, 2259, 426, 77, -271, -212], [-560, -1590, -4416, 622, -2594, 868, -710, 562, -396], [20352, 8119, -2112, 437, 1113, 1276, -207, 922, -947], [-12793, 371, -535, 707, -2107, 74, 81, 836, 292], [-11401, -256, -2409, 508, -334, -2244, 154, -1417, -394], [26084, 5876, -1786, 1542, 4232, -306, 972, -326, 200], [21316, 8353, 3006, -747, 848, 578, -27, 1109, 360], [-24115, 6698, -1796, -2163, 227, -361, 776, -1362, 320], [-36325, 3507, -4213, 1173, 579, -1646, -463, 440, 966], [38687, -8006, 1398, 2297, -55, -1547, 780, 1094, 236], [-6026, -4654, -130, 156, 396, -2850, 150, -212, 220], [-2055, 2967, -3261, -481, -2065, -840, -39, -532, 198], [2345, 529, -749, 1067, 137, 162, 1179, 368, 4], [-44629, 975, 2552, -466, -753, 15, -999, 301, 32], [22323, 904, -793, 338, 224, -952, -816, 60, 461], [17567, 1580, -1324, 113, 947, -133, -522, 56, 574], [14219, 2418, 775, 2640, -1967, -1246, -1628, 835, -98], [1402, 4064, -6326, -152, 4112, -1282, -426, -353, -771], [34507, 1435, -606, 700, -215, -1355, -279, 625, 1726], [-9829, -3542, -2156, -535, 4396, -1329, 132, -310, 1036], [8790, -5715, 681, 598, 2582, 2213, -367, -298, -1104], [11637, 5399, -665, -559, 2229, 1170, 999, -745, 57], [30227, 592, -2273, 486, 891, -1312, 1958, -79, -156], [-7818, -7360, 30, 528, -772, 442, 38, 1111, 829], [-81, -9534, 3585, -594, 3455, 920, -204, 937, -642], [10986, 2161, -2051, -1808, -1776, -865, -1179, 298, 572], [-8229, -4643, 8382, -320, 467, -67, -1897, 305, -216], [-16093, -10668, 3256, -359, -1867, 1109, 190, 826, 902], [7286, 10411, 1646, 151, 2359, -2064, 99, -903, -528], [23712, 1541, -1163, 2370, -1843, -1325, 1039, -2177, 315], [-17812, 3858, 737, -447, -3127, 1173, -1044, 616, -539], [-9724, 13692, -2539, -805, 1130, 809, -1318, 334, -3], [-1612, 9694, -496, 290, 1344, -1964, -870, 8, -62], [51277, -2859, -1020, 598, 875, 737, 763, -195, -402], [-29398, 10558, -1682, 3022, 1274, 528, -1442, 1016, -1188], [13404, 8861, -4719, -1628, 2889, 573, 847, -1747, -1155], [-5932, 1415, 732, -891, 1021, 1836, 569, 1666, 249], [20931, 5791, 2446, -2496, 2981, 917, 729, -815, -236], [32583, 14046, 2418, -2013, -1603, -333, -180, -412, -698], [13958, 15620, 473, 495, -528, -299, 424, 91, -948], [-11377, 2306, 3082, 1063, -1812, -91, -728, 1358, -1294], [44953, -215, -1670, 1730, 2653, -3031, 1647, -857, 504], [21202, 6312, -2071, -2077, -1687, 1673, 1486, -2036, 1071], [8697, -4235, 947, 239, 7149, -1556, 257, -175, 109], [22925, -2659, 638, -442, 2031, -391, 603, 497, 380], [11561, -11051, -6394, -12, 2053, 539, 1175, -39, -162], [38846, -1363, -4563, -1572, 1496, 739, -471, -294, -1036], [31877, 7650, -4014, -2337, 724, -429, -44, -504, -1152], [-40417, 14112, -4115, 846, -1472, 1512, -864, 746, -1595], [-4907, 7395, -3043, 3265, -3576, 382, -119, -204, -262], [-1503, -15277, 1352, 842, -1186, 1301, 849, -539, 678], [44985, 3038, 3972, -81, 90, -33, 664, 1120, 1090], [-11615, -6744, 1896, 2437, -2197, -3261, 198, -614, 832], [20290, 9016, -102, 1178, 5550, 598, -972, 292, -830], [-13324, 7260, -2973, 311, -303, 945, 1218, -2, 511], [-6075, -9868, 1095, -148, -382, 530, -536, -598, -265], [-26896, -5600, 1886, -274, -798, 1452, -54, 983, -431], [3816, 11181, -4230, -293, 2855, 3072, -517, 378, -1195], [24498, -9743, 4433, -296, -11, 655, -1093, -969, -463], [28834, -7184, -2771, -487, 1648, 91, 1410, 554, -1175], [-2865, -11259, 1527, -849, 5014, -1602, 1377, -1307, 1027], [325, 7793, -1764, -634, 1561, -793, -1181, 943, -532], [-31335, 7903, -2235, 37, -403, 370, -489, 1411, 239], [-102, -8347, -6572, 641, -3096, -846, 209, 1569, 1138], [13875, -4423, -8301, 917, -6695, 1032, 219, 34, 268], [-18899, -9893, 1245, -1819, -6257, 2810, 159, 727, -1129], [-15, 21938, -767, 840, -623, -1840, -84, -1891, 348], [40546, -670, -821, -2025, -1798, -1101, -974, -63, -654], [50143, -12008, 1088, 323, 1754, -2971, 662, -1430, -342], [-13211, 10111, -1001, -121, -1697, -3140, 1245, -830, 846], [-28756, -3326, 2325, 241, 1099, -1001, 2000, -782, 549], [-27693, -5295, -4398, 174, 1161, -1627, -399, 1672, 893], [7291, 11177, -6096, 894, -1117, -2871, 183, 1095, -792], [19334, 6995, -7536, 821, -4397, -2520, -31, 1160, 301], [-54085, -9602, -7252, 1215, 1456, -3171, 86, -211, 901], [-2596, 1815, -3576, 1115, -1859, 3106, 1041, -112, -537], [5833, -16135, 2932, 72, 3739, 495, -2169, 1459, -1356], [7975, -21101, 3821, -1631, 3343, 1578, -1095, -928, -1292], [-17516, -10212, -6312, 1430, 3790, 3374, 952, -506, -1502], [-23580, -10645, -593, -288, 730, -347, 2227, 416, -22], [16073, 2638, -1374, -1545, 124, 81, -1964, -300, 414], [-62051, 633, 7144, 1612, 1169, -215, 805, 1556, -15], [5701, -7885, 6727, 1825, 2037, 1420, 1457, 670, 1580], [-29593, -8437, -743, 483, 1161, 1390, -195, -514, 24], [19973, 3143, 6802, -516, -685, 3251, -773, 982, 117], [-29124, 7274, -1131, 1717, -5827, -879, 176, 1078, 1543], [28849, 9077, -4611, 405, -1, -1138, 1185, -89, 817], [-28432, -11772, 199, 2131, 2964, -2343, 2112, -753, -346], [-55348, -7239, -8105, 1716, -3976, -449, -231, 340, 448], [-10772, 1276, -1756, -686, 4818, 958, 2864, 244, 1092], [50068, -8995, 3071, -4170, -1097, 5037, -677, -697, -2573], [-15073, 22196, -7262, 547, 4362, -3031, 274, -1626, 520], [-71083, 4567, -1794, -2180, 653, -419, -1401, -1772, 1081], [-34196, -2253, 4170, 2391, -592, -1650, 2047, -899, 118], [57317, -19670, -2952, -1269, -404, 505, 1450, 161, 437], [-26396, 5445, 936, -727, -3632, -1658, -1643, -865, -704], [-7300, 3844, 4742, -116, -2698, 1448, -1664, 2340, 810], [-14470, 26477, -1162, 723, 1493, 1508, 65, 1743, -660], [39989, -10333, 2769, 567, 389, 3146, 1095, -369, 1337], [73751, 8885, -6612, -2010, -2175, 1455, -749, -865, -30], [1312, -5652, 461, 119, -2892, 2689, 384, -103, 574], [3996, -8884, -1008, -1368, 3902, -1042, -350, 1451, 887], [1871, -13105, 2342, 2800, -3177, -349, -395, 249, 854], [-20364, 3161, 5667, -3524, 496, 2323, -803, 214, -1718], [-24136, -8466, -1863, 1477, -744, 3015, 2492, 2518, 685], [-3383, -5381, -3323, 363, -3889, -2012, 371, -1971, 177], [34111, 15439, 4370, -120, -8225, 263, -1525, -164, 237], [28316, -11375, 2600, -1093, 733, 450, -1451, 1277, -90], [-8211, 15618, -1852, 643, -4571, -4335, -80, -632, -570], [32645, -11894, 6116, 1625, -392, -691, 1944, -378, -412], [-34733, 21135, 2161, 365, -1007, 4250, 109, 1404, 418], [-28280, 1555, 7343, 828, -285, 2457, 1717, 333, -789], [-11397, -11307, -8098, 1652, 3869, -1333, 2121, 588, 449], [-46879, -8382, 916, 173, -935, 2801, 268, -1596, -3044], [-81020, -21678, 1329, 25, 4486, 1061, 1394, -2103, -720], [23108, 23798, -2658, 1032, -4698, 2730, 178, -836, -1020], [-1716, 8226, 2559, -2399, -771, -341, -1072, -1220, -1171], [-15503, 14297, 7202, -1126, 217, 4055, -1885, 1783, 256], [34221, 3165, 426, 918, 1019, -1171, 1847, -1831, -1796], [13114, -5978, 4409, 1831, 3587, -2375, 828, 2216, 1603], [-89737, -2637, 3805, -81, 3903, -2422, 533, -326, 922], [46439, 991, 1120, -476, 3157, -2435, -391, -3723, -288], [-25302, 4485, 9881, -4842, -1016, 2101, -747, 960, -1318], [62577, -14546, 417, -5040, 1118, -56, -326, -2108, 1137], [3522, 6296, 3123, -2889, -3882, -2495, -548, -113, 782], [-1846, -8646, 3998, -38, 1160, -254, -248, -1451, 401], [-480, 2180, -3064, 6140, -6152, 1296, 1340, 366, 82], [-44873, 5494, 1644, -3365, -7248, 4677, 92, -1148, 328], [37107, -12124, 8120, 1317, 744, 1867, 1610, 900, 2954], [33356, 13351, -475, -2308, -583, -715, -1043, 1695, -2477], [-27388, -14788, -2438, 1758, 660, 1154, 316, -1798, 64], [-66704, -4023, -10673, 1400, -712, -413, 913, 1184, 400], [34063, -11146, 2670, 1027, -4406, -819, -818, 1671, 57], [29461, 10873, 9354, -2646, -5723, 1071, -1825, 1335, -384], [15520, -19193, 5292, -4707, 4299, -506, -1065, -1473, 1304], [-4154, 4773, -5611, 1276, -1165, -3933, -839, 2690, -212], [-28446, 20102, -7937, -327, 5026, 2765, 686, -9, -1260], [-10836, -12388, -2516, -2682, 7056, 2734, -148, 158, -130], [-43761, -4123, -418, -6, -4525, -919, 587, 2537, -1772], [-26626, 16852, 3305, -2589, -2069, 5297, -2238, 1974, -1055], [-29807, -6620, 904, 2383, -2828, -2845, -1318, -2482, 532], [-18023, 12692, -7564, -1627, -742, -4183, 56, -453, -187], [-1831, -3442, 7278, -3055, -2162, 3293, 1324, 38, 1738], [-7957, 16210, 5313, -742, 5219, 1056, 1330, -56, 825], [61709, -11648, 11527, -2890, 5030, 1538, -810, -1073, -2238], [-18857, 10680, 4175, -780, 810, 664, -318, 221, -822], [19443, -1192, -991, 262, 2274, -4920, 816, -1620, -1057], [14917, -4482, 1968, 2093, -5343, 791, 1000, 2400, 2418], [63932, -8192, -8604, 84, 3526, 1212, -1000, -116, -1064], [-51397, -24467, 10286, -474, 3, 1817, -645, 1451, 1088], [-33189, 15471, 6266, -362, -2255, 3325, -629, 434, 11], [-7297, 8134, -4639, -2538, -3736, 946, -1866, 1898, 131], [33677, 9338, -691, 1364, 1458, 1120, -1738, -1896, -931], [11910, 27402, -2264, -708, -4150, 2650, -2440, 21, -1723], [-53192, 5081, 3228, 5069, -2899, -2696, -995, 75, -1584], [10473, 18279, -5275, 3035, 4823, -3246, 3597, -444, 1010], [-61093, -989, -4392, 608, 675, 723, 1113, 327, 1282], [-8219, -8233, 2060, -4270, -2340, 1093, 977, 991, -1026], [47880, 21539, -5421, 1776, -1551, 1025, 1445, -249, -463], [72100, 4165, -3681, -2956, -1481, -39, -2849, 1767, 453], [-26907, -19006, 7866, 3669, -1242, 533, 156, 1186, 1622], [-68112, -15102, -214, 864, 974, 690, 1158, 304, -1052], [12183, 19776, -1892, 413, 4112, 2265, -1534, -580, -2712], [36502, -13466, 12300, -320, -5196, -368, 1880, 197, 327], [-33867, 18432, -606, 213, 4542, -1841, -1550, -1216, -1530], [-30610, -907, -5360, 1359, 6434, -2724, 801, -887, 806], [25004, 4054, 8184, 1476, -2544, -3550, 3182, -434, 2128], [43327, -1995, -847, -1549, 630, 2526, -1543, 2241, -1791], [23440, -4791, -576, 6355, -1769, -3550, -559, 133, -216], [7489, -13902, -4072, 311, -1022, -993, -800, 1650, 1494], [-17313, -10298, -14981, 726, 652, 1038, 762, 1748, 355], [-16882, -21693, 3719, 6, 5200, 3123, -2741, 72, 442], [-17644, -8375, -3669, -4570, -3246, 3593, 1739, 113, -997], [-64013, -10926, -12864, 2927, 10026, -6287, 2912, -644, 2948], [30868, 14232, -9082, 5340, -5484, 3656, -520, 820, -186], [13627, 30305, 14, -1564, -11073, -889, -1621, -1287, 1360], [561, -14435, 1618, -3984, -2051, 713, 531, -325, -1300], [-38957, -33663, 3714, 168, 3101, 357, 87, -1269, -866], [-33014, -5238, -3036, -84, -3896, 1006, 1866, -1374, 1948], [-3696, -9882, 6287, 5703, -3767, -3155, -2592, 1254, 1619], [66071, -18190, 275, -212, 3587, -344, 980, -3127, 1550], [90642, -26995, 10594, -3243, 4573, 6106, -531, 1153, 114], [74081, -13406, 4598, 2687, -5482, -3693, -556, -796, -320], [-45199, -9108, 13220, -2919, -6194, 6707, 1010, -1262, 2044], [73283, -400, -10896, 1113, 5028, -3307, 2416, -1831, -1685], [-14627, -48193, 7175, -3119, 7838, -1474, 397, -1810, 876], [-131838, 29924, -8678, -246, 2340, -3922, -1280, -1396, -126], [80879, -3505, 11803, 1331, 209, 1274, 995, -641, -1491], [39197, 19088, -20255, -2336, 1998, 824, 258, -5, -996]]
